# Changelog

## 1.0.0 (2022-03-09)

### Dev

* Remove deprecated python 3.6 and 3.7 support.
* Add python 3.11.
* Add typing /w mypy.

## 0.1.2 (2021-11-02)

### Dev

* Fix pyproject links.

## 0.1.1 (2021-11-02)

* Update documentation.

### Dev

* Move CI from TravisCI to Github Actions.
* Switch to Poetry.

## 0.1.0 (2019-08-06)

* Add specification basics.
* Add error reporting.
